#Packages
library("agricolae")
library("car")
library("ggplot2")
library(dplyr)#for manipulating data

st.err <- function(x) {sd(x)/sqrt(length(x))} #funsction to determine the standard error

#Create the environment
setwd("/Volumes/users9/Documents/02 Data/01 EXP1  Nutrilim")

Nt=read.csv("2015NutriLimNt.csv") #read the data

#----------------------------------------------------------------------------- Analysis per amendment
N_A<-Nt
N_A$SITE<-factor(ifelse(N_A$SOIL=="NUB","Native",ifelse(
  N_A$SOIL=="NLB", "Native", ifelse(
    N_A$SOIL=="NHB","Native", "Pine"))))

N_A$BURN<-factor(ifelse(N_A$SOIL=="NLB","Low Burn",ifelse(
  N_A$SOIL=="PLB","Low Burn",ifelse(
    N_A$SOIL=="NHB","High Burn",ifelse(
      N_A$SOIL=="PHB","High Burn","Unburnt")))))

#20171107--------
TEST_A<-N_A%>%
  filter(SITE=="Native" & BURN=="Unburnt")
anova(lm(N~TREAT, data=TEST_A))

TEST_B<-N_A%>%
  filter(SITE=="Native" & BURN=="Low Burn")
anova(lm(N~TREAT, data=TEST_B))

TEST_C<-N_A%>%
  filter(SITE=="Native" & BURN=="High Burn")
anova(lm(N~TREAT, data=TEST_C))

TEST_D<-N_A%>%
  filter(SITE=="Pine" & BURN=="Unburnt")
anova(lm(N~TREAT, data=TEST_D))

TEST_E<-N_A%>%
  filter(SITE=="Pine" & BURN=="Low Burn")
anova(lm(N~TREAT, data=TEST_E))

TEST_F<-N_A%>%
  filter(SITE=="Pine" & BURN=="High Burn")
anova(lm(N~TREAT, data=TEST_F))


TEST_POOLED<-N_A%>%
  filter(BURN=="Unburnt")
anova(lm(N~TREAT, data=TEST_POOLED))


TEST_POOLED<-N_A%>%
  filter(BURN!="Unburnt")
anova(lm(N~TREAT, data=TEST_POOLED))

HSD.test(aov(N~TREAT, data=TEST_POOLED), c("TREAT"), console=TRUE, alpha=0.05)

#20171107 END---------------


N_A<-N_A[,-1]

N_T<-aggregate(N_A$N, list(BURN=N_A$BURN, SITE=N_A$SITE, TREAT=N_A$TREAT), FUN=mean) #mean per treatment
se<-aggregate(N_A$N, list(BURN=N_A$BURN, SITE=N_A$SITE, TREAT=N_A$TREAT), FUN=st.err) #SE per treatment
colnames(N_T)<-c("BURN","SOIL","TREAT","X") #correct the collumn names

N_T$se<-se$x #combine the dfs
N_T$ymax<-N_T$X+N_T$se
N_T$ymin<-N_T$X-N_T$se  #these variables are to map the error bars.

#remove(N_A)
remove(se)
remove(Nt)

N_T$TREAT<-factor(ifelse(
  N_T$TREAT=="C","C+",ifelse(
    N_T$TREAT=="N","N+",ifelse(
      N_T$TREAT=="P","P+",ifelse(
        N_T$TREAT=="CN","C+N+",ifelse(
          N_T$TREAT=="CP","C+P+",ifelse(
            N_T$TREAT=="NP","N+P+",ifelse(
              N_T$TREAT=="CNP","C+N+P+","Blank")))))))) #Correct the treatment names

N_T$TREAT<-factor(N_T$TREAT,levels(N_T$TREAT)[c(1,2,8,5,6,7,3,4)]) #correct the order
N_T$BURN<-factor(N_T$BURN,levels(N_T$BURN)[c(3,2,1)])

N_T<-N_T[order(N_T$TREAT),] #sort
N_T<-N_T[order(N_T$BURN),] #sort
N_T<-N_T[order(N_T$SOIL),]

ggplot(data=N_T, aes(x=TREAT, y=X, ymin=ymin, ymax=ymax)) +
  facet_grid(SOIL~BURN) +
  geom_bar(stat="identity", fill="grey50") + 
  geom_errorbar(aes(width=0.2)) +
  xlab("Treatment") +
  ylab(expression(paste("AN (",mu,"gN/gSoil)"))) +
  scale_y_continuous(expand = c(0, 0), limits=c(0,1000)) +
  theme(panel.background=element_rect(fill="white"), 
        panel.border = element_rect(linetype = "solid", fill = NA),
        strip.text.y=element_text(size=10),
        strip.text.x=element_text(angle=0, size=10),
        axis.text.x=element_text(angle = +90, hjust = 1)) +
  ggsave("nutrilim_Nt1.svg",width=6, height=6)

N_U<-subset(N_A, N_A$BURN=="Unburnt")
N_LB<-subset(N_A, N_A$BURN=="Low Burn")
N_HB<-subset(N_A, N_A$BURN=="High Burn")

N_NUB<-subset(N_U,N_U$SITE=="Native")
N_NLB<-subset(N_LB,N_LB$SITE=="Native")
N_NHB<-subset(N_HB,N_HB$SITE=="Native")
N_PUB<-subset(N_U,N_U$SITE=="Pine")
N_PLB<-subset(N_LB,N_LB$SITE=="Pine")
N_PHB<-subset(N_HB,N_HB$SITE=="Pine")


model<-aov(N~TREAT, data=N_NUB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(N~TREAT, data=N_NLB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(N~TREAT, data=N_NHB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(N~TREAT, data=N_PUB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(N~TREAT, data=N_PLB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(N~TREAT, data=N_PHB)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)


#----------------------------------------------------------------------------- Analysis per fire history
N<-Nt

N$BURN<-factor(ifelse(N$SOIL=="NLB","Burnt",ifelse(
  N$SOIL=="PLB","Burnt",ifelse(
    N$SOIL=="NHB","Burnt",ifelse(
      N$SOIL=="PHB","Burnt","Unburnt")))))

N<-N[,-1]

se<-aggregate(N$N, list(BURN=N$BURN, TREAT=N$TREAT), FUN=st.err) #SE per burn
N<-aggregate(N$N, list(BURN=N$BURN, TREAT=N$TREAT), FUN=mean) #mean per burn
colnames(N)<-c("BURN","TREAT","X") #correct the collumn names

N$se<-se$x #combine the dfs
N$ymax<-N$X+N$se
N$ymin<-N$X-N$se  #these variables are to map the error bars.

remove(se) #cleanup

N$TREAT<-factor(ifelse(
  N$TREAT=="C","C+",ifelse(
    N$TREAT=="N","N+",ifelse(
      N$TREAT=="P","P+",ifelse(
        N$TREAT=="CN","C+N+",ifelse(
          N$TREAT=="CP","C+P+",ifelse(
            N$TREAT=="NP","N+P+",ifelse(
            N$TREAT=="CNP","C+N+P+","Blank")))))))) #Correct the treatment names

N$TREAT<-factor(N$TREAT,levels(N$TREAT)[c(1,2,8,5,6,7,3,4)]) #correct the order
N$BURN<-factor(N$BURN,levels(N$BURN)[c(2,1)])
N<-N[order(N$TREAT),] #sort
N<-N[order(N$BURN),] #sort

ggplot(data=N, aes(x=TREAT, y=X, ymin=ymin, ymax=ymax)) +
  facet_wrap(~BURN) +
  geom_bar(stat="identity", fill="grey50") + 
  geom_errorbar(aes(width=0.2)) +
  xlab("Treatment") +
  ylab(expression(paste("AN (",mu,"gN/gSoil)"))) +
  scale_y_continuous(expand = c(0, 0), limits=c(0,1000)) +
  theme(panel.background=element_rect(fill="white"), 
        panel.border = element_rect(linetype = "solid", fill = NA),
        strip.text.x=element_text(angle=0, size=12),
        axis.text.x=element_text(angle = +90, hjust = 1)) +
  ggsave("nutrilim_N1.svg",width=6, height=6)


Nt$BURN<-factor(ifelse(Nt$SOIL=="NLB","B",ifelse(
  Nt$SOIL=="PLB","B",ifelse(
    Nt$SOIL=="NHB","B",ifelse(
      Nt$SOIL=="PHB","B","U")))))

N_B<-subset(Nt, Nt$BURN=="B")
N_U<-subset(Nt, Nt$BURN=="U")

model<-aov(N~TREAT, data=N_U)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)

model<-aov(N~TREAT, data=N_B)
cv.model(model)
df<-df.residual(model)
MSerror<-deviance(model)/df
HSD<-HSD.test(model,c("TREAT"),console=TRUE,alpha=0.05)